//----------------------------------------------------------------------------//
//=Purpose: Exercise 3.2 of Beyond Classic Designs & Analysis for Health      //
//          Data in Singapore (27 June to 8 July 2022)                        //
//
//=Data required: 
//  - full_cohort.dta
//
//=Stata packages/libraries required:
//
//=Created by:
//  - Zihan 
//  - Zilu Feng
//  - Francesca Graziano 
//  - Chuen Seng Tan
//  - Marie Reilly
//
//=Changes (if any):
//  -DDMMYYYY: Describe 
//
//----------------------------------------------------------------------------//

//-Set the working directory to the data folder where the datasets are saved:
cd "D:/nbox/Education/Marie_short_course/Singapore course 2022/20220602/exercises/data"

////////////////////////////////////////////////////////////////////////////////
//                               Question 1      
//
//-1. This exercise makes use the dataset full_cohort.dta, which is a simulated 
//    data set  of 50,000 cohort members, where the outcome of interest is time 
//    from enrolment to coronary heart disease with event indicator. The 
//    variables recorded for this cohort include: 
//
//    * t time from enrolment into the cohort to coronary heart disease (in years)
//    * event (event indicator 1=coronary heart disease, 0=censored)
//    * Age (Age, in years)
//    * Gender (1=Male, 0=Female)
//    * Chol (cholesterol in mg/dL)
//    * HDL (high-density lipoprotein in mg/dL)
//    * SBP (systolic blood pressure in mmHg)
//    * Treat (antihypertensive treatment status 1=Yes, 0=No) 
//    * Smoke (smoking status 1=Yes, 0=No)
////////////////////////////////////////////////////////////////////////////////


////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (i)     
//
//-(i)	Create a categorical variable for age with the following intervals: 
//      <=49, 50-59, 60-69, 70-79, ≥80
////////////////////////////////////////////////////////////////////////////////

//load the dataset:
use full_cohort.dta, clear

//create age category, such as 28-49; 50-59......:
egen agecat=cut(Age), at(28,50,60,70,80,97)
	
//label agecat:
label variable agecat "age_category"
label define agecat1 28 "28-49" 50 "50-59" 60 "60-69" 70 "70-79" 80 "80-97"
label values agecat agecat1  
codebook agecat


////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (ii)     
//
//-(ii)	For each of the other continuous covariates (Chol, HDL, and SBP) 
//      center them at their mean values (i.e. subtract the mean from each value). 
////////////////////////////////////////////////////////////////////////////////

//center cholesterol at its mean:
summarize Chol, meanonly
gen centered_Chol = Chol - r(mean)

//center HDL at its mean:
summarize HDL, meanonly
gen centered_HDL = HDL - r(mean)

//center SBP at its mean:
summarize SBP, meanonly
gen centered_SBP = SBP - r(mean)

save centered.dta, replace

////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (iii)     
//
//-(iii) Run a Cox regression analysis of the whole cohort with these new 
//       variables created in part (i) and (ii) and the remaining binary 
//       variables (Gender: 1=Male, 0=Female, Treat: 1=Yes, 0=No, 
//       Smoke: 1=Yes, 0=No). 
////////////////////////////////////////////////////////////////////////////////

//run cox
stset t, failure(event==1) 
stcox centered_Chol centered_HDL centered_SBP Gender Treat Smoke i.agecat


////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (iv)     
//
//-(iv) Assume the investigators wanted to study coronary heart disease by year 
//      10 by sampling an exclusive case-control dataset and conducting a 
//      logistic regression. Draw an exclusive 1:1 case-control sample at year 
//      10 that is matched on sex and age category. Save a copy of this data set 
//      for part (v).
////////////////////////////////////////////////////////////////////////////////

//identify the complete case-control data at year 10 
keep if (t>10 & event==0) | (event==1)
//create the binary outcome at year 10 
gen binary=event
replace binary=0 if t>10 & event==1  

//set a seed using a random number and generate match pairs:
set seed 1810
ccmatch Gender agecat, cc(binary) id(id)
drop if match==.
	
//save this data set:
save match.dta, replace


////////////////////////////////////////////////////////////////////////////////
//                               Question 1 (v)     
//
//-(v) Run a conditional logistic regression analysis of the data from (iv) and 
//     compare the results to the full cohort in part (iii).
////////////////////////////////////////////////////////////////////////////////

//run conditional logistic:
clogit binary centered_Chol centered_HDL centered_SBP Treat Smoke, group(match) or

	
////////////////////////////////////////////////////////////////////////////////
//                               Question 2 (i)     
//
//-(i) Run Cox regression analyses of the whole cohort to obtain the crude HR 
//     for Gender and the HR adjusted for age-category. 
////////////////////////////////////////////////////////////////////////////////

use centered.dta, clear
stset t, failure(event==1)

//crude HR for Gender:
stcox Gender

//HR adjusted for age-category:
stcox Gender i.agecat


////////////////////////////////////////////////////////////////////////////////
//                               Question 2 (ii)     
//
//-(ii) Draw a 1:5 nested case-control sample (i.e. 5 controls for each case) 
//      using simple random sampling (use a seed!) and save a copy of the data 
//      before proceeding.  Run a conditional logistic regression of Gender 
//      using your nested case-control sample and compare the results with the 
//      crude HR for gender obtained from the whole cohort Cox regression.
////////////////////////////////////////////////////////////////////////////////

//set a seed using a random number and create a nested case–control dataset from the cohort dataset that has been stset, matching cases to controls based on analysis time. Match 5 controls for each case:
set seed 1810
quietly: sttocc, number(5)

//note: this generates a variable "_set", which indicates matched group.*
save match2.dta, replace
	
//conditional logistic model:
clogit event Gender, group(_set) or


////////////////////////////////////////////////////////////////////////////////
//                               Question 2 (iii)     
//
//-(iii) Draw a nested case- control sample that is matched on age category. 
//       Compare the OR for gender from a  conditional logistic regression 
//       analysis to the age-adjusted HR from the Cox regression of the whole 
//       cohort.
////////////////////////////////////////////////////////////////////////////////

use centered, clear
stset t, failure(event==1)
	
//set a seed using a random number and create a nested case–control dataset from the cohort, match on analysis time and categorical variable "agecat". Match 5 controls for each case:
set seed 1810
quietly: sttocc, match(agecat) number(5)

//conditional logistic model adjusted for agecat:
clogit event Gender, group(_set) or

//See 2 (i)age-adjusted HR from the Cox regression of the whole cohort and the estimates are comparable


////////////////////////////////////////////////////////////////////////////////
//                               Question 2 (iv)     
//
//-(iv) Use the nested case-control data from (ii) to run the full model in 
//      Question 1 (i.e., all the variables listed in part (iii), categorical 
//      age, mean centered HDL, Chol and SBP, and binary treatment, gender and 
//      smoking), and compare the results to the Cox regression of the whole 
//      cohort. 
////////////////////////////////////////////////////////////////////////////////

use match2, clear
	
//conditional logistic model (full model):
clogit event centered_Chol centered_HDL centered_SBP Gender Treat Smoke, group(_set) or
